Package: gentransmuted
Type: Package
Title: Estimation and Other Tools for Generalized Transmuted Models
Version: 1.0
Date: 2025-07-12
Authors@R: c(person(given = c("Yolanda", "M."), family = "Gomez", role = "aut"), person(given = c("Hector", "W."), family = "Gomez", role = "aut"), person(given = c("Barry", "C."), family = "Arnold", role = "aut"), person(given = c("Diego", "I."), family = "Gallardo", role = c("aut", "cre"), email = "dgallardo@ubiobio.cl"))
Description: Provide estimation and data generation tools for a generalization of the 
	transmuted distributions discussed in Shaw and Buckley (2007).
	See <doi:10.48550/arXiv.0901.0434> for more information.
Depends: R (>= 4.0.0)
Imports: pracma, VGAM
License: GPL (>= 2)
NeedsCompilation: no
Packaged: 2025-07-17 01:01:10 UTC; Diego
Author: Yolanda M. Gomez [aut],
  Hector W. Gomez [aut],
  Barry C. Arnold [aut],
  Diego I. Gallardo [aut, cre]
Maintainer: Diego I. Gallardo <dgallardo@ubiobio.cl>
Repository: CRAN
Date/Publication: 2025-07-19 09:50:02 UTC
Built: R 4.3.3; ; 2025-07-19 11:51:26 UTC; unix
