export("choose.compound", "dcompound", "dEXP", "dEXP2", "dMO", "dMO2",
       "dSB", "estimate.compound", "pcompound", "pEXP", "pEXP2", "pMO",
       "pMO2", "pSB", "qEXP", "qEXP2", "qcompound","qMO", "qMO2", "qSB",
       "rcompound", "rEXP", "rEXP2", "rMO", "rMO2", "rSB")
importFrom("stats","coef","optim","pnorm","dnorm",
	"plogis","qnorm","runif","pexp","dexp","qexp","rexp","dgamma",
	"pgamma","qgamma","rgamma","dlnorm","plnorm","qlnorm","rlnorm",
	"pbeta","qbeta","rbeta","dbeta","dcauchy","pcauchy","qcauchy","rcauchy")
importFrom("VGAM", "dgumbel","pgumbel","qgumbel","rgumbel","dbisa","pbisa",
	"qbisa","rbisa","dkumar","pkumar","qkumar","rkumar","dlomax",
	"plomax","qlomax","rlomax","dparetoII","pparetoII","qparetoII","rparetoII")
importFrom("pracma", "hessian")

