rMO2 <-
function(n, theta=1)
{
if (is.null(n)) stop("sample size must be specified")
if (round(n) != n | n <= 0) stop("sample size must be a positive integer")
if(theta<0) stop("theta must be less than 0")
qMO2(runif(n), theta=theta)
}
