rSB <-
function(n, lambda=0)
{
if (is.null(n)) stop("sample size must be specified")
if (round(n) != n | n <= 0) stop("sample size must be a positive integer")
if(lambda< -1 | lambda>1) stop("lambda must be between -1 and 1")
qSB(runif(n), lambda)
}
