qEXP <-
function(p, alpha=1, lower.tail = TRUE, log.p = FALSE)
{
if(alpha<0) stop("alpha must be less than 0")
Qy<-(1/alpha)*log(p)
Qy <- ifelse(p <= 0, -Inf, Qy)
Qy <- ifelse(p >= 1, Inf, Qy)
if(log.p == FALSE) Qy <- exp(Qy)
if(lower.tail==FALSE) Qy<-1-Qy
Qy
}
